package com.jz.dmp.modules.controller;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.bean.DmpProjectDto;
import com.jz.dmp.modules.controller.bean.DmpProjectRequest;
import com.jz.dmp.modules.model.DmpProject;
import com.jz.dmp.modules.service.DmpProjectService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

/**
 * 项目信息Controller
 * @author ybz
 *
 */
@RestController
@RequestMapping("/dmp/project")
@Api(tags = "项目信息")
public class DmpProjectController {
	
	@Autowired
	private DmpProjectService dmpProjectService;
	
	
	/**列表查询项目信息
	 * @param dmpProjectRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/findListWithPage")
	@ApiOperation(value = "分頁列表查询项目信息", notes = "分頁列表查询项目信息")
	public PageInfoResponse<DmpProjectDto> findListWithPage(@RequestBody DmpProjectRequest dmpProjectRequest, HttpServletRequest httpRequest){
		PageInfoResponse<DmpProjectDto> pageInfo = new PageInfoResponse<DmpProjectDto>();
		try {
			pageInfo = dmpProjectService.findListWithPage(dmpProjectRequest, httpRequest);
		} catch (Exception e) {
			pageInfo.setMessage("查询失败");
			pageInfo.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return pageInfo;
	}
	
	/**软删除项目信息
	 * @param id
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/softDelete")
	@ApiOperation(value = "软删除项目信息", notes = "软删除项目信息")
	@ApiImplicitParam(name = "id", value = "项目信息主键")
	public BaseResponse softDelete(@RequestParam(name = "id", required = true ) Integer id, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			baseResponse = dmpProjectService.softDeleteById(id, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("软删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**新增项目信息
	 * @param dmpProjectRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/add")
	@ApiOperation(value = "新增项目信息", notes = "新增项目信息")
	public BaseBeanResponse<DmpProject> add(@RequestBody DmpProject dmpProject, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpProject> baseBeanResponse = new BaseBeanResponse<DmpProject>();
		try {
			baseBeanResponse = dmpProjectService.add(dmpProject, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("新增失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
}
