package com.jz.dmp.modules.service.sys.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.constant.ResultCode;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.sys.bean.DmpCodeDictionaryBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpCodeDictionaryDto;
import com.jz.dmp.modules.controller.sys.bean.DmpCodeDictionaryRequest;
import com.jz.dmp.modules.dao.sys.DmpCodeDictionaryMapper;
import com.jz.dmp.modules.model.DmpCodeDictionary;
import com.jz.dmp.modules.service.sys.DmpCodeDictionaryService;

/**
 * 编码字典服务的实现?
 * @author ybz
 *
 */
@Service("dmpCodeDictionaryService")
public class DmpCodeDictionaryServiceImpl extends BaseService implements DmpCodeDictionaryService {
	
	private static Logger logger = LoggerFactory.getLogger(DmpCodeDictionaryServiceImpl.class);
	
	@Autowired
	private DmpCodeDictionaryMapper dmpCodeDictionaryMapper;

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpCodeDictionaryService#findList(com.ycxc.vmts.controller.bean.DmpCodeDictionaryRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpCodeDictionaryDto> findList(DmpCodeDictionaryRequest dmpCodeDictionaryRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpCodeDictionaryDto> pageInfoResponse = new PageInfoResponse<>();
		
		Map<String, Object> param = new HashMap<>();
		//主键
		if (dmpCodeDictionaryRequest.getCodeId() != null) {
			param.put("codeId", dmpCodeDictionaryRequest.getCodeId());
		}
		//编码分类
		if (!StringUtils.isEmpty(dmpCodeDictionaryRequest.getCodeType())) {
			param.put("codeType", dmpCodeDictionaryRequest.getCodeType());
		}
		//编码CODE
		if (!StringUtils.isEmpty(dmpCodeDictionaryRequest.getCodeKey())) {
			param.put("codeKey", dmpCodeDictionaryRequest.getCodeKey());
		}
		//编码值
		if (!StringUtils.isEmpty(dmpCodeDictionaryRequest.getCodeValue())) {
			param.put("codeValue", dmpCodeDictionaryRequest.getCodeValue());
		}
		//备注
		if (!StringUtils.isEmpty(dmpCodeDictionaryRequest.getRemark())) {
			param.put("remark", dmpCodeDictionaryRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpCodeDictionaryRequest.getDataStatus())) {
			param.put("dataStatus", dmpCodeDictionaryRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpCodeDictionaryRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpCodeDictionaryRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpCodeDictionaryRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpCodeDictionaryRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpCodeDictionaryRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpCodeDictionaryRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpCodeDictionaryRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpCodeDictionaryRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpCodeDictionaryRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpCodeDictionaryRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpCodeDictionaryRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpCodeDictionaryRequest.getUpdateTimeEnd());
		}
		
		PageHelper.startPage(dmpCodeDictionaryRequest.getPageNum(), dmpCodeDictionaryRequest.getPageSize());
		List<DmpCodeDictionaryDto> list = dmpCodeDictionaryMapper.findList(param);
		PageInfo<DmpCodeDictionaryDto> pageInfo = new PageInfo<>(list);
		
		pageInfoResponse.setCode(ResultCode.SUCCESS.val());
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}
	

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpCodeDictionaryService#add(com.ycxc.vmts.entity.DmpCodeDictionary, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpCodeDictionary> add(DmpCodeDictionary dmpCodeDictionary, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpCodeDictionary> baseBeanResponse = new BaseBeanResponse<>();
		
		/*$*setCodeIdCodeReplace*$*/
		//创建人
		dmpCodeDictionary.setCreateUserId(getHttpRequestUserId(httpRequest));
		//创建时间
		dmpCodeDictionary.setCreateTime(new Date());
		
		dmpCodeDictionaryMapper.insertSelective(dmpCodeDictionary);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpCodeDictionary);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpCodeDictionaryService#edit(com.ycxc.vmts.entity.DmpCodeDictionary, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpCodeDictionary> edit(DmpCodeDictionary dmpCodeDictionary, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpCodeDictionary> baseBeanResponse = new BaseBeanResponse<>();
		
		//修改人
		dmpCodeDictionary.setUpdateUserId(getHttpRequestUserId(httpRequest));
		//修改时间
		dmpCodeDictionary.setUpdateTime(new Date());
		
		dmpCodeDictionaryMapper.updateByPrimaryKeySelective(dmpCodeDictionary);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpCodeDictionary);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpCodeDictionaryService#findById(com.ycxc.vmts.controller.bean.DmpCodeDictionaryRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpCodeDictionaryDto> findById(DmpCodeDictionaryRequest dmpCodeDictionaryRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpCodeDictionaryDto> baseBeanResponse = new BaseBeanResponse<>();
		
		DmpCodeDictionaryDto dmpCodeDictionaryDto = dmpCodeDictionaryMapper.findById(dmpCodeDictionaryRequest.getCodeId());
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpCodeDictionaryDto);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpCodeDictionaryService#deleteById(com.ycxc.vmts.controller.bean.DmpCodeDictionaryRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteById(DmpCodeDictionaryRequest dmpCodeDictionaryRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseResponse baseResponse = new BaseResponse();
		
		dmpCodeDictionaryMapper.deleteByPrimaryKey(dmpCodeDictionaryRequest.getCodeId());
		
		baseResponse.setCode(ResultCode.SUCCESS.val());
		baseResponse.setMessage("删除成功");
		
		return baseResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpCodeDictionaryService#addBatch(com.ycxc.vmts.controller.bean.DmpCodeDictionaryVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpCodeDictionaryBatch> addBatch(DmpCodeDictionaryBatch dmpCodeDictionaryBatch, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpCodeDictionaryBatch> baseBeanResponse = new BaseBeanResponse<>();
		
		List<DmpCodeDictionary> dmpCodeDictionarys = dmpCodeDictionaryBatch.getDmpCodeDictionarys();
		
		if (CollectionUtils.isEmpty(dmpCodeDictionarys)) {
			baseBeanResponse.setCode(ResultCode.PARAMS_ERROR.val());
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}
		
		dmpCodeDictionarys = dmpCodeDictionarys.stream().map(dmpCodeDictionary -> {
			/*$*setCodeIdCodeReplace*$*/
			//创建人
			try {
				dmpCodeDictionary.setCreateUserId(getHttpRequestUserId(httpRequest));
			} catch (Exception e) {
				logger.info(e.getMessage());
				e.printStackTrace();
			}
			//创建时间
			dmpCodeDictionary.setCreateTime(new Date());
			
			return dmpCodeDictionary;
		}).collect(Collectors.toList());
		
		dmpCodeDictionaryMapper.insertBatch(dmpCodeDictionarys);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpCodeDictionaryBatch);
		
		return baseBeanResponse;
	}
	
}
